Female baby name data provided by Statistics Norway. This includes all names with at least 4 uses.
1 |
A data frame with five variables: first_name, year,
Percent (the proportion of births in that year with that name),
Count (the number of births in that year with that name)and Sex.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.